#!/bin/bash
# AB-README_RUNME.sh
#
# DESCRIPTION:
# 	This script and associated data files produce high quality PDFS of the Holy-Bible---Arabic---Arabic-Van-Dyck-Bible
#	Developed and Coprighted by Nainoia Inc, PO Box 462, Bellefonte, PA 16823, (814) 470-8028, http://NAINOIA-INC.signedon.net
#	Copyright 2020, Creative Commons Attribution No Derivative Works 4.0, https://creativecommons.org/licenses/by-nd/4.0/
#
# OPERATION:
#	AB-README_RUNME.sh	`						// Help and cat the script
#	AB-README_RUNME.sh ALL						// Build all PDFs types
#	AB-README_RUNME.sh +PO +LU +NT +ON +OO +EP	// Build all selected type(s):  POD | LULU | NEW TESTAMENT | ONLINE | ONE-ONLINE | EPUB COVER
#
# FILETYPES:
#	[prefix].[suffix]							// Online cover page + interior
#	[prefix]---STUDY.[suffix]					// Online cover page + interior, wide margin study format
#	[prefix]---POD_INTERIOR.[suffix]			// Print on demand interior for Amazon KDP specifications
#	[prefix]---POD_COVER.[suffix]				// Print on demand cover for Amazon KDP specifications
#	[prefix]---POD_INTERIOR_22.[suffix]			// Print on demand interior 22 books for Amazon KDP specifications
#	[prefix]---POD_COVER_22.[suffix]			// Print on demand cover 22 books for Amazon KDP specifications
#	[prefix]---POD_INTERIOR_NT.[suffix]			// Print on demand interior New Testament for Amazon KDP specifications
#	[prefix]---POD_COVER_NT.[suffix]			// Print on demand cover New Testament for Amazon KDP specifications
#	[prefix]---POD_LULU.[suffix]				// Print on demand interior paperback for LuLu specifications
#	[prefix]---POD_COVER_LULU.[suffix]			// Print on demand cover for LuLu specifications
#	[prefix]---POD_LULU_22.[suffix]				// Print on demand interior 22 books paperback for LuLu specifications
#	[prefix]---POD_COVER_LULU_22.[suffix]		// Print on demand cover 22 books for LuLu specifications
#	[prefix]---POD_LULU_NT.[suffix]				// Print on demand interior paperback New Testament for LuLu specifications
#	[prefix]---POD_COVER_LULU_NT.[suffix]		// Print on demand cover New Testament for LuLu specifications
#	[prefix]---POD_LULU_HARD.[suffix]			// Print on demand interior hardback for LuLu specifications
#	[prefix]---POD_COVER_LULU_HARD.[suffix]		// Print on demand cover hardback for LuLu specifications
#
error_exit()
{
	echo "${1:-"Unknown Error"}" 1>&2
	exit 1
}
SPEED="../AB-Speedata/bin/sp"

if [ "$#" = "0" ] ; then cat "$0" ; fi
name="---Aionian-Edition"
if ( [ "$1" = "+ALL" ] || [[ "${@#+ON}" != "$@" ]] || [[ "${@#+OO}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi
name="---Aionian-Edition---STUDY"
if ( [ "$1" = "+ALL" ] || [[ "${@#+ON}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi
name="---EPUB_COVER"
if ( [ "$1" = "+ALL" ] || [[ "${@#+EP}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi

name="---POD_INTERIOR"
if ( [ "$1" = "+ALL" ] || [[ "${@#+PO}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi
name="---POD_COVER"
if ( [ "$1" = "+ALL" ] || [[ "${@#+PO}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg  --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi

name="---POD_INTERIOR_22"
if ( [ "$1" = "+ALL" ] || [[ "${@#+PO}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi
name="---POD_COVER_22"
if ( [ "$1" = "+ALL" ] || [[ "${@#+PO}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg  --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi

name="---POD_INTERIOR_NT"
if ( [ "$1" = "+ALL" ] || [[ "${@#+NT}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi
name="---POD_COVER_NT"
if ( [ "$1" = "+ALL" ] || [[ "${@#+NT}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg  --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi

name="---POD_LULU"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi
name="---POD_COVER_LULU"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi

name="---POD_LULU_22"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi
name="---POD_COVER_LULU_22"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi

name="---POD_LULU_NT"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi
name="---POD_COVER_LULU_NT"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi

name="---POD_LULU_HARD"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi
name="---POD_COVER_LULU_HARD"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config2.cfg --jobname=Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Arabic---Arabic-Van-Dyck-Bible$name.pdf"; fi

echo "SPEEDATA Holy-Bible---Arabic---Arabic-Van-Dyck-Bible: SCRIPT SUCCESS!"
